@@ -18,23 +18,12 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #
 
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
+from unittest import mock
 import unittest
 
-from six import PY2
 from gtkdoc import common
 
 
-if PY2:
-    openname = '__builtin__.open'
-else:
-    openname = 'builtins.open'
-
-
 class TestUpdateFileIfChanged(unittest.TestCase):
 
     @mock.patch('os.path.exists')
@@ -46,7 +35,7 @@ class TestUpdateFileIfChanged(unittest.TestCase):
         self.assertTrue(res)
 
     @mock.patch('os.path.exists')
-    @mock.patch(openname, mock.mock_open(read_data='bar'))
+    @mock.patch('builtins.open', mock.mock_open(read_data='bar'))
     @mock.patch('os.unlink')
     def test_FilesAreTheSame(self, os_unlink, os_path_exists):
         os_path_exists.return_value = True
@@ -60,19 +49,19 @@ class TestGetModuleDocDir(unittest.TestCase):
     @mock.patch('subprocess.check_output')
     def test_ReturnsPath(self, subprocess_check_output):
         subprocess_check_output.return_value = '/usr'
-        self.assertEquals(common.GetModuleDocDir('glib-2.0'), '/usr/share/gtk-doc/html')
+        self.assertEqual(common.GetModuleDocDir('glib-2.0'), '/usr/share/gtk-doc/html')
 
 
 class TestCreateValidSGMLID(unittest.TestCase):
 
     def test_AlreadyValid(self):
-        self.assertEquals(common.CreateValidSGMLID('x'), 'x')
+        self.assertEqual(common.CreateValidSGMLID('x'), 'x')
 
     def test_SpecialCharsBecomeDash(self):
-        self.assertEquals(common.CreateValidSGMLID('x_ y'), 'x--y')
+        self.assertEqual(common.CreateValidSGMLID('x_ y'), 'x--y')
 
     def test_SpecialCharsGetRemoved(self):
-        self.assertEquals(common.CreateValidSGMLID('x,;y'), 'xy')
+        self.assertEqual(common.CreateValidSGMLID('x,;y'), 'xy')
 
 
 if __name__ == '__main__':
